{% extends "base.html" %}
{% import "_macros/posts.html" as posts %}

{% block content %}
    <h2 class="text-center">{{ gettext('All articles tagged with <code>%(value)s</code>',value=tag) }} </h2>
     {{ posts.list(site.tagged(tag)) }}
{% endblock %}