{% extends "base.html" %}
{% import "_macros/posts.html" as posts %}
{% block content %}
    <h2>{{ gettext('Archived of %(value)s' , value = archive.title) }}</h2>
    <h3>{{ gettext('Total %(value)s', value= archive.count) }}</h3>
    {{ posts.list(archive.posts) }}
{% endblock %}